==> rh-management-component-1.2.1-sources.jar: org/exoplatform/rhmanagement/dto/EmployeesDTO.java <==
/*
 * Copyright (C) 2003-2016 eXo Platform SAS.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package org.exoplatform.rhmanagement.dto;

public class EmployeesDTO {

  private  long id;

  private  String userId;

  private  String name;

  private  String avatar;

  private  String email;

  private  String jobTitle;

  private  String gender;

  private  String phone;

  private UserRHDataDTO     hrData;

  private Boolean           expanded;

  private Float daysToConsume;

    public long getId() {
      return id;
    }

    public void setId(long id) {
      this.id = id;
    }

    public String getUserId() {
      return userId;
    }

    public void setUserId(String userId) {
      this.userId = userId;
    }

    public String getName() {
      return name;
    }

    public void setName(String name) {
      this.name = name;
    }

    public String getAvatar() {
      return avatar;
    }

    public void setAvatar(String avatar) {
      this.avatar = avatar;
    }

    public String getEmail() {
      return email;
    }

    public void setEmail(String email) {
      this.email = email;
    }

    public String getJobTitle() {
      return jobTitle;
    }

    public void setJobTitle(String jobTitle) {
      this.jobTitle = jobTitle;
    }

    public String getGender() {
      return gender;
    }

    public void setGender(String gender) {
      this.gender = gender;
    }

    public String getPhone() {
      return phone;
    }

    public void setPhone(String phone) {
      this.phone = phone;
    }

    public UserRHDataDTO getHrData() {
      return hrData;
    }

    public void setHrData(UserRHDataDTO hrData) {
      this.hrData = hrData;
    }

  public Boolean getExpanded() {
    return expanded;
  }

  public void setExpanded(Boolean expanded) {
    this.expanded = expanded;
  }

  public Float getDaysToConsume() {
    return daysToConsume;
  }

  public void setDaysToConsume(Float daysToConsume) {
    this.daysToConsume = daysToConsume;
  }
}

==> rh-management-component-1.3.2-sources.jar: org/exoplatform/rhmanagement/dto/EmployeesDTO.java <==
/*
 * Copyright (C) 2003-2016 eXo Platform SAS.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package org.exoplatform.rhmanagement.dto;

public class EmployeesDTO {

  private  long id;

  private  String userId;

  private  String name;

  private  String avatar;

  private  String email;

  private  String jobTitle;

  private  String gender;

  private  String phone;

  private UserRHDataDTO     hrData;

  private Boolean           expanded;

  private Float daysToConsume;

  private String functionalManagerName;

  private String hierarchicalManagerName;

    public long getId() {
      return id;
    }

    public void setId(long id) {
      this.id = id;
    }

    public String getUserId() {
      return userId;
    }

    public void setUserId(String userId) {
      this.userId = userId;
    }

    public String getName() {
      return name;
    }

    public void setName(String name) {
      this.name = name;
    }

    public String getAvatar() {
      return avatar;
    }

    public void setAvatar(String avatar) {
      this.avatar = avatar;
    }

    public String getEmail() {
      return email;
    }

    public void setEmail(String email) {
      this.email = email;
    }

    public String getJobTitle() {
      return jobTitle;
    }

    public void setJobTitle(String jobTitle) {
      this.jobTitle = jobTitle;
    }

    public String getGender() {
      return gender;
    }

    public void setGender(String gender) {
      this.gender = gender;
    }

    public String getPhone() {
      return phone;
    }

    public void setPhone(String phone) {
      this.phone = phone;
    }

    public UserRHDataDTO getHrData() {
      return hrData;
    }

    public void setHrData(UserRHDataDTO hrData) {
      this.hrData = hrData;
    }

  public Boolean getExpanded() {
    return expanded;
  }

  public void setExpanded(Boolean expanded) {
    this.expanded = expanded;
  }

  public Float getDaysToConsume() {
    return daysToConsume;
  }

  public void setDaysToConsume(Float daysToConsume) {
    this.daysToConsume = daysToConsume;
  }

  public String getFunctionalManagerName() {
    return functionalManagerName;
  }

  public void setFunctionalManagerName(String functionalManagerName) {
    this.functionalManagerName = functionalManagerName;
  }

  public String getHierarchicalManagerName() {
    return hierarchicalManagerName;
  }

  public void setHierarchicalManagerName(String hierarchicalManagerName) {
    this.hierarchicalManagerName = hierarchicalManagerName;
  }
}
